@@ -15,6 +15,7 @@ from cli_4666 import cnmc_4666
 from cli_4667 import cnmc_4667
 from cli_4_2015 import cnmc_4_2015
 from cli_6181 import cnmc_6181
+from cli_8_2021 import cnmc_8_2021  
 
 
 @click.group()
@@ -1210,5 +1211,5 @@ def cir_3_2015_f3(**kwargs):
 
 
 cli = click.CommandCollection(sources=[
-    cnmc, cnmc_4666, cnmc_4667, cnmc_4_2015, cnmc_6181
+    cnmc, cnmc_4666, cnmc_4667, cnmc_4_2015, cnmc_6181, cnmc_8_2021
 ])
