@@ -1,36 +1,44 @@
 from __future__ import absolute_import
-from libcnmc.models.cnmcmodel import CNMCModel
-
 from collections import OrderedDict
 
+from libcnmc.models.cnmcmodel import CNMCModel
 from libcnmc.models.fields import String, Integer, Decimal
 
 
-class F4Res4131(CNMCModel):
+class F2Res4131(CNMCModel):
     """
-        Class for forth file of resolution 4131(Posiciones)
+        Class for second file of resolution 4131(BT)
     """
+
     schema = OrderedDict([
         ('identificador', String()),
         ('cini', String()),
-        ('denominacion', String()),
+        ('origen', String()),
+        ('destino', String()),
         ('codigo_ccuu', String()),
-        ('codigo_ccaa', Integer()),
-        ('nivel_tension', Decimal(3)),
-        ('participacion', Decimal(3)),
+        ('codigo_ccaa_1', Integer()),
+        ('codigo_ccaa_2', Integer()),
+        ('participacion', String()),
         ('fecha_aps', String()),
         ('fecha_baja', String()),
-        ('estado', Integer()),
+        ('numero_circuitos', Integer()),
+        ('numero_conductores', Integer()),
+        ('nivel_tension', Decimal(3)),
+        ('longitud', Decimal(3)),
+        ('intensidad_maxima', Decimal(3)),
+        ('seccion', Decimal(3)),
+        ('capacidad', Decimal(3)),
+        ('propiedad', String()),
+        ('estado', Integer())
     ])
 
     @property
     def ref(self):
-        return self.store.identificador
+        return self.store.identificador[1:]
 
     def __cmp__(self, other):
         comp_fields = [
-            'cini', 'codigo_ccuu', 'nivel_tension', 'participacion',
-            'denominacion'
+            'longitud', 'cini', 'seccion', 'codigo_ccuu', 'nivel_tension'
         ]
         if self.diff(other, comp_fields):
             return True
