@@ -6,21 +6,19 @@ from collections import OrderedDict
 from libcnmc.models.fields import String, Integer, Decimal
 
 
-class F4Res4666(CNMCModel):
+class F6Res4666(CNMCModel):
     """
-        Class for forth file of resolution 4666(Posiciones)
+        Class for sixth file of resolution 4666(Despatxos)
     """
+
     schema = OrderedDict([
         ('identificador', String()),
         ('cini', String()),
         ('denominacion', String()),
-        ('codigo_ccuu', String()),
-        ('codigo_ccaa', Integer()),
-        ('nivel_tension', Decimal(3)),
-        ('participacion', Decimal(3)),
         ('fecha_aps', String()),
         ('fecha_baja', String()),
-        ('estado', Integer()),
+        ('valor_inversion', Decimal(3)),
+        ('estado', Integer())
     ])
 
     @property
@@ -28,10 +26,7 @@ class F4Res4666(CNMCModel):
         return self.store.identificador
 
     def __cmp__(self, other):
-        comp_fields = [
-            'cini', 'codigo_ccuu', 'nivel_tension', 'participacion',
-            'denominacion', 'fecha_aps'
-        ]
+        comp_fields = ['cini', 'fecha_aps']
         if self.diff(other, comp_fields):
             return True
         else:
