@@ -4,9 +4,9 @@ from collections import OrderedDict
 from libcnmc.models.fields import String, Integer, Decimal
 
 
-class F3Res4667(CNMCModel):
+class F6Res4667(CNMCModel):
     """
-    Class for Otros file of 4667 
+    Class for Despachos file of 4667 
     """
 
     schema = OrderedDict([
@@ -15,10 +15,9 @@ class F3Res4667(CNMCModel):
         ('identificador_py', String()),
         ('cini_prv', String()),
         ('codigo_ccaa', Integer()),
-        ('anio_prev_es', Integer()),
-        ('vol_inv_prev', Decimal(10)),
+        ('anio_prev_aps', Integer()),
+        ('vol_inv_prv', Decimal(10)),
         ('ayudas_prv', Decimal(10)),
-        ('financiacion_prv', Decimal(8)),
         ('vpi_retribuible_prv', Decimal(10)),
         ('estado', Integer())
     ])
